@@ -2,6 +2,9 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Bokmerker",
+    "You bookmarked \"%s\"" : "Du bokmerket \"%s\"",
+    "%1$s bookmarked \"%2$s\"" : "%1$s bokmerket \"%2$s\"",
+    "Someone bookmarked \"%s\"" : "Noen bookmerket \"%s\"",
     "You deleted \"%s\"" : "Du slettet \"%s\"",
     "%1$s deleted \"%2$s\"" : "%1$s slettet \"%2$s\"",
     "Someone deleted \"%s\"" : "Noen slettet \"%s\"",
@@ -18,15 +21,37 @@ OC.L10N.register(
     "You shared folder \"%s\" with someone" : "Du delte mappen \"%s\" med noen",
     "%1$s shared folder \"%2$s\" with you" : "%1$s delte mappen \"%2$s\" med deg",
     "Someone shared folder \"%s\" with you" : "Noen delte mappen \"%s\" med deg",
+    "You unshared folder \"%1$s\" with %2$s" : "Du stoppet å dele mappen \"%1$s\" med %2$s",
+    "You unshared folder \"%s\" with someone" : "Du stoppet å dele mappen \"%s\" med noen",
+    "%1$s unshared folder \"%2$s\" with you" : "%1$s stoppet å dele mappen \"%2$s\" med deg",
+    "Someone unshared folder \"%s\" with you" : "Noen stoppet å dele mappen \"%s\" med deg",
     "No file provided for import" : "Ingen fil valgt for import",
     "Unsupported file type for import" : "Usupportert filtype for import",
+    "Bookmarks Backups" : "Sikkerhetskopi av bokmerker",
+    "Bookmarks shared by %s" : "Bokmerker delt av %s",
+    "Frequent bookmarks" : "Hyppige bokmerker",
+    "Recent bookmarks" : "Nylige bokmerker",
+    "Bookmark" : "Legg til som bokmerke",
+    "Bookmark deleted" : "Bokmerke slettet",
+    "Bookmark created" : "Bokmerke opprettet",
+    "Bookmark moved" : "Bokmerke flyttet",
+    "Bookmark updated" : "Bokmerke oppdatert",
+    "Create bookmark" : "Opprett bokmerke",
+    "Takes a link and adds it to your collection of bookmarks." : "Tar en lenke å legger den til i den i bokmerke-samlingen din.",
+    "A Bookmark manager for Nextcloud" : "En bokmerkebehandler for Nextcloud",
+    "Enter new title" : "Skriv inn en ny tittel",
+    "Select bookmark" : "Velg bokmerke",
     "Details" : "Detaljer",
     "Rename" : "Gi nytt navn",
     "Copy link" : "Kopier lenke",
     "Move" : "Flytt",
+    "Add to folders" : "Legg i mapper",
     "Delete" : "Slett",
+    "Do you really want to delete this bookmark?" : "Er du sikker på at du vil slette dette bokmerket?",
+    "Link copied to clipboard" : "Lenke kopiert til utklippstavlen",
     "Select all" : "Velg alle",
     "Go back" : "Gå tilbake",
+    "Share folder" : "Del mappe",
     "Select one or more tags" : "Velg en eller flere merkelapper",
     "New" : "Ny",
     "New folder" : "Ny mappe",
